@@ -132,6 +132,10 @@ eel_open_with_dialog_finalize (GObject *object)
 static void
 eel_open_with_dialog_destroy (GtkObject *object)
 {
+	EelOpenWithDialog *dialog;
+
+	dialog = EEL_OPEN_WITH_DIALOG (object);
+
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
 
@@ -174,6 +178,7 @@ check_application (EelOpenWithDialog *dialog)
 	if (error) {
 		eel_show_error_dialog (_("Could not run application"),
 				       error->message,
+				       _("Could not run application"),
 				       GTK_WINDOW (dialog));
 		g_error_free (error);
 		retval = FALSE;
@@ -189,6 +194,7 @@ check_application (EelOpenWithDialog *dialog)
 
 		eel_show_error_dialog (_("Could not find application"),
 				       error_message,
+				       _("Could not find application"),
 				       GTK_WINDOW (dialog));
 		g_free (error_message);
 		retval = FALSE;
@@ -219,6 +225,7 @@ get_app_name (EelOpenWithDialog *dialog)
 	if (error) {
 		eel_show_error_dialog (_("Could not run application"),
 				       error->message,
+				       _("Could not run application"),
 				       GTK_WINDOW (dialog));
 		g_error_free (error);
 
@@ -280,12 +287,12 @@ add_or_find_application (EelOpenWithDialog *dialog)
 		} else {
 			app = NULL;
 		}
-		g_free (app_name);
 	}
 
 	if (!app) {
 		eel_show_error_dialog (_("Could not add application"),
 				       _("Could not add application to the application database"),
+				       _("Could not add application"),
 				       GTK_WINDOW (dialog));
 	}
 
@@ -508,23 +515,8 @@ static int
 compare_applications (GMenuTreeEntry *a,
 		      GMenuTreeEntry *b)
 {
-	const char *name_a = gmenu_tree_entry_get_name (a);
-	const char *name_b = gmenu_tree_entry_get_name (b);
-
-	if (name_a == NULL && name_b == NULL) {
-		return 0;
-	}
-
-	if (name_a == NULL) {
-		return -1;
-	}
-
-	if (name_b == NULL) {
-		return 1;
-	}
-
-	return g_utf8_collate (name_a,
-			       name_b);
+	return g_utf8_collate (gmenu_tree_entry_get_name (a),
+			       gmenu_tree_entry_get_name (b));
 }
 
 static GSList *
@@ -533,7 +525,6 @@ get_all_applications_from_dir (GMenuTreeDirectory *directory,
 {
 	GSList *contents;
 	GSList *l;
-	const char *exec;
 
 	contents = gmenu_tree_directory_get_contents (directory);
 
@@ -547,15 +538,7 @@ get_all_applications_from_dir (GMenuTreeDirectory *directory,
 				break;
 
 			case GMENU_TREE_ITEM_ENTRY:
-				exec = gmenu_tree_entry_get_exec ((GMenuTreeEntry*)item);
-				/* Only add items that actually accept a file */
-				if (exec != NULL &&
-				    (strstr (exec,"%U") != NULL ||
-				     strstr (exec,"%u") != NULL ||
-				     strstr (exec,"%f") != NULL ||
-				     strstr (exec,"%F") != NULL)) {
-					list = g_slist_prepend (list, item);
-				}
+				list = g_slist_prepend (list, item);
 				break;
 
 			default:
@@ -576,7 +559,7 @@ get_all_applications (void)
 	GMenuTreeDirectory *root;
 	GSList             *retval;
 
-	tree = gmenu_tree_lookup ("applications.menu", GMENU_TREE_FLAGS_INCLUDE_NODISPLAY);
+	tree = gmenu_tree_lookup ("applications.menu", GMENU_TREE_FLAGS_NONE);
 
 	root = gmenu_tree_get_root_directory (tree);
 
@@ -591,77 +574,6 @@ get_all_applications (void)
 	return retval;
 }
 
-static gboolean
-eel_open_with_search_equal_func (GtkTreeModel *model,
-				 int column,
-				 const char *key,
-				 GtkTreeIter *iter,
-				 gpointer user_data)
-{
-	char *normalized_key;
-	char *name, *normalized_name;
-	char *path, *normalized_path;
-	char *basename, *normalized_basename;
-	gboolean ret;
-
-	if (key != NULL) {
-		normalized_key = g_utf8_casefold (key, -1);
-		g_assert (normalized_key != NULL);
-
-		ret = TRUE;
-
-		gtk_tree_model_get (model, iter,
-				    COLUMN_NAME, &name,
-				    COLUMN_PATH, &path,
-				    -1);
-
-		if (name != NULL) {
-			normalized_name = g_utf8_casefold (name, -1);
-			g_assert (normalized_name != NULL);
-
-			if (strncmp (normalized_name, normalized_key, strlen (normalized_key)) == 0) {
-				ret = FALSE;
-			}
-
-			g_free (normalized_name);
-		}
-
-		if (ret && path != NULL) {
-			/* chop any argument specifiers */
-			if (strchr (path, ' ') != NULL) {
-				*(strchr (path, ' ')) = '\0';
-			}
-
-			normalized_path = g_utf8_casefold (path, -1);
-			g_assert (normalized_path != NULL);
-
-			basename = g_path_get_basename (path);
-			g_assert (basename != NULL);
-
-			normalized_basename = g_utf8_casefold (basename, -1);
-			g_assert (normalized_basename != NULL);
-
-			if (strncmp (normalized_path, normalized_key, strlen (normalized_key)) == 0 ||
-			    strncmp (normalized_basename, normalized_key, strlen (normalized_key)) == 0) {
-				ret = FALSE;
-			}
-
-			g_free (basename);
-			g_free (normalized_basename);
-			g_free (normalized_path);
-		}
-
-		g_free (name);
-		g_free (path);
-		g_free (normalized_key);
-
-		return ret;
-	} else {
-		return TRUE;
-	}
-}
-
-
 
 static gboolean
 eel_open_with_dialog_add_items_idle (EelOpenWithDialog *dialog)
@@ -689,8 +601,7 @@ eel_open_with_dialog_add_items_idle (EelOpenWithDialog *dialog)
 		GtkTreeIter     iter;
 		GtkTreePath    *path;
 
-		const char *name = gmenu_tree_entry_get_name (entry);
-		if (!name || (prev_name && strcmp (name, prev_name) == 0)) {
+		if (prev_name && strcmp (gmenu_tree_entry_get_name (entry), prev_name) == 0) {
 			gmenu_tree_item_unref (entry);
 			continue;
 		}
@@ -716,9 +627,6 @@ eel_open_with_dialog_add_items_idle (EelOpenWithDialog *dialog)
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (dialog->details->program_list), 
 				 GTK_TREE_MODEL (dialog->details->program_list_store));
-	gtk_tree_view_set_search_equal_func (GTK_TREE_VIEW (dialog->details->program_list),
-					     eel_open_with_search_equal_func,
-					     NULL, NULL);
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	column = gtk_tree_view_column_new ();
@@ -880,7 +788,6 @@ eel_open_with_dialog_instance_init (EelOpenWithDialog *dialog)
 {
 	GtkWidget *hbox;
 	GtkWidget *vbox;
-	GtkWidget *vbox2;
 	GtkWidget *label;
 	GtkWidget *align;
 	GtkWidget *scrolled_window;
@@ -891,28 +798,23 @@ eel_open_with_dialog_instance_init (EelOpenWithDialog *dialog)
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Open With"));
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
 
-	vbox = gtk_vbox_new (FALSE, 12);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
-
-	vbox2 = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (vbox), vbox2, TRUE, TRUE, 0);
-
+	vbox = gtk_vbox_new (FALSE, 6);
 	dialog->details->label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (dialog->details->label), 0.0, 0.5);
 	gtk_label_set_line_wrap (GTK_LABEL (dialog->details->label), TRUE);
-	gtk_box_pack_start (GTK_BOX (vbox2), dialog->details->label,
+	gtk_box_pack_start (GTK_BOX (vbox), dialog->details->label,
 			    FALSE, FALSE, 0);
 	gtk_widget_show (dialog->details->label);
 
 
 	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-	gtk_widget_set_size_request (scrolled_window, 400, 300);
+	gtk_widget_set_size_request (scrolled_window, 400, 400);
 	
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window),
 					     GTK_SHADOW_IN);
@@ -924,14 +826,14 @@ eel_open_with_dialog_instance_init (EelOpenWithDialog *dialog)
 					   FALSE);
 	gtk_container_add (GTK_CONTAINER (scrolled_window), dialog->details->program_list);
 	
-	gtk_box_pack_start (GTK_BOX (vbox2), scrolled_window, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), scrolled_window, TRUE, TRUE, 0);
 
 	dialog->details->desc_label = gtk_label_new (_("Select an application to view its description."));
 	gtk_misc_set_alignment (GTK_MISC (dialog->details->desc_label), 0.0, 0.5);
 	gtk_label_set_justify (GTK_LABEL (dialog->details->desc_label), GTK_JUSTIFY_LEFT);
 	gtk_label_set_line_wrap (GTK_LABEL (dialog->details->desc_label), TRUE);
 	gtk_label_set_single_line_mode (GTK_LABEL (dialog->details->desc_label), FALSE);
-	gtk_box_pack_start (GTK_BOX (vbox2), dialog->details->desc_label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), dialog->details->desc_label, FALSE, FALSE, 0);
 	
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->details->program_list));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
@@ -951,8 +853,9 @@ eel_open_with_dialog_instance_init (EelOpenWithDialog *dialog)
 	gtk_widget_show_all (vbox);
 
 
-	expander = gtk_expander_new_with_mnemonic (_("_Use a custom command"));
-	gtk_box_pack_start (GTK_BOX (vbox), expander, FALSE, FALSE, 0);
+	expander = gtk_expander_new_with_mnemonic (_("Use a _custom command"));
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), expander,
+			    FALSE, FALSE, 0);
 	g_signal_connect_after (expander, "activate", G_CALLBACK (expander_toggled), dialog);
 
 	gtk_widget_show (expander);
@@ -1040,7 +943,6 @@ set_uri_and_mime_type (EelOpenWithDialog *dialog,
 {
 	char *label;
 	char *name;
-	char *emname;
 	GnomeVFSURI *vfs_uri;
 
 	dialog->details->uri = g_strdup (uri);
@@ -1062,7 +964,6 @@ set_uri_and_mime_type (EelOpenWithDialog *dialog,
 		dialog->details->mime_type =
 			g_strdup_printf ("application/x-extension-%s",
 					 extension);
-		/* the %s here is a file extension */
 		dialog->details->mime_description =
 			g_strdup_printf (_("%s document"), extension);
 		dialog->details->new_glob = g_strdup_printf ("*.%s",
@@ -1083,9 +984,7 @@ set_uri_and_mime_type (EelOpenWithDialog *dialog,
 		dialog->details->mime_description = description;
 	}
 
-	emname = g_strdup_printf ("<i>%s</i>", name);
-	label = g_strdup_printf (_("Open %s and other files of type \"%s\" with:"), emname, dialog->details->mime_description);
-	g_free (emname);
+	label = g_strdup_printf (_("Open <i>%s</i> and other files of type \"%s\" with:"), name, dialog->details->mime_description);
 
 	gtk_label_set_markup (GTK_LABEL (dialog->details->label), label);
 
@@ -1128,7 +1027,7 @@ eel_open_with_dialog_get_type (void)
 	static GType type = 0;
 
 	if (!type) {
-		const GTypeInfo info = {
+		static const GTypeInfo info = {
 			sizeof (EelOpenWithDialogClass),
 			NULL,
 			NULL,
